@@ -17,7 +17,7 @@
 # along with this library; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/examples/testdnd.pl,v 1.2 2003/09/22 00:04:23 rwmcfa1 Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/examples/testdnd.pl,v 1.3 2004/01/17 08:45:25 muppetman Exp $
 #
 
 # TITLE: DND
@@ -292,9 +292,9 @@ use constant  TARGET_STRING => 0;
 use constant  TARGET_ROOTWIN => 1;
 
 @target_table = (
-	{'target' => "STRING", 'flags' => 0, 'info' => TARGET_STRING},
-	{'target' => "text/plain", 'flags' => 0, 'info' => TARGET_STRING},
-	{'target' => "application/x-rootwin-drop", 'flags' => 0, 'info' => TARGET_ROOTWIN},
+	{'target' => "STRING", 'flags' => [], 'info' => TARGET_STRING},
+	{'target' => "text/plain", 'flags' => [], 'info' => TARGET_STRING},
+	{'target' => "application/x-rootwin-drop", 'flags' => [], 'info' => TARGET_ROOTWIN},
 );
 
 sub target_drag_leave {
